rnalysis.enrichment.EnrichmentProcessing
========================================

.. currentmodule:: rnalysis.enrichment

.. autoclass:: EnrichmentProcessing

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
    :toctree:
   
      ~EnrichmentProcessing.__init__
      ~EnrichmentProcessing.difference
      ~EnrichmentProcessing.enrich_big_table
      ~EnrichmentProcessing.go_enrichment
      ~EnrichmentProcessing.intersection
      ~EnrichmentProcessing.save_txt
      ~EnrichmentProcessing.symmetric_difference
      ~EnrichmentProcessing.union
   
   

   
   
